package org.jeecg.modules.adminuser.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.PasswordUtil;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.adminuser.entity.AdminUser;
import org.jeecg.modules.adminuser.service.IAdminUserService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecg.modules.system.entity.SysUser;
import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;

 /**
 * @Description: 医生用户管理
 * @Author: jeecg-boot
 * @Date:   2022-12-16
 * @Version: V1.0
 */
@Api(tags="医生用户管理")
@RestController
@RequestMapping("/adminDoctorUser/adminUser")
@Slf4j
public class AdminDoctorUserController extends JeecgController<AdminUser, IAdminUserService> {
	@Autowired
	private IAdminUserService adminUserService;
	
	/**
	 * 分页列表查询
	 *
	 * @param adminUser
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "用户管理-分页列表查询")
	@ApiOperation(value="用户管理-分页列表查询", notes="用户管理-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<AdminUser>> queryPageList(AdminUser adminUser,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req,String ssname,String ssphone,String ssksname,String ssdwname) {
		QueryWrapper<AdminUser> queryWrapper = QueryGenerator.initQueryWrapper(adminUser, req.getParameterMap());
		queryWrapper.eq( "doctor_and_specialist","1" );
		if (ssname != null){
			queryWrapper.like("name",ssname);
		}
		if (ssphone != null){
			queryWrapper.like("phone",ssphone);
		}
		if (ssksname != null){
			queryWrapper.like("ksname",ssksname);
		}
		if (ssdwname != null){
			queryWrapper.like("dwname",ssdwname);
		}
		Page<AdminUser> page = new Page<AdminUser>(pageNo, pageSize);
		IPage<AdminUser> pageList = adminUserService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param adminUser
	 * @return
	 */
	@AutoLog(value = "用户管理-添加")
	@ApiOperation(value="用户管理-添加", notes="用户管理-添加")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody AdminUser adminUser) {
		adminUser.setDoctorAndSpecialist("1");
		String salt = oConvertUtils.randomGen(8);
		adminUser.setSalt(salt);
		if (adminUser.getPassword()==null){
			adminUser.setPassword( "123456" );
		}
		if (adminUser.getPassword().equals( "" )){
			adminUser.setPassword( "123456" );
		}
		adminUser.setWisMhu( "允许" );
		adminUser.setWisWjdc( "允许" );
		String passwordEncode = PasswordUtil.encrypt(adminUser.getPhone(), adminUser.getPassword(), salt);
		adminUser.setPassword(passwordEncode);
		adminUserService.save(adminUser);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param adminUser
	 * @return
	 */
	@AutoLog(value = "用户管理-编辑")
	@ApiOperation(value="用户管理-编辑", notes="用户管理-编辑")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody AdminUser adminUser) {
		adminUserService.updateById(adminUser);
		return Result.OK("编辑成功!");
	}


	 @RequestMapping(value = "/updatePassWord", method = {RequestMethod.PUT,RequestMethod.POST})
	 public Result<String> updatePassWord(@RequestBody AdminUser adminUser) {
		 if (!adminUser.getPassword().equals( "" )){
			 AdminUser u = adminUserService.getOne(new LambdaQueryWrapper<AdminUser>().eq(AdminUser::getPhone,
					 adminUser.getPhone()));
			 if (u == null) {
				 return Result.error("用户不存在！");
			 }
			 String salt = oConvertUtils.randomGen(8);
			 adminUser.setSalt(salt);
			 String password = adminUser.getPassword();
			 String passwordEncode = PasswordUtil.encrypt(adminUser.getPhone(), password, salt);
			 adminUser.setPassword(passwordEncode);
			 adminUserService.updateById(adminUser);
			 return Result.OK("修改成功!");
		 }else {
			 return Result.error("不能为空！");
		 }
	 }
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "用户管理-通过id删除")
	@ApiOperation(value="用户管理-通过id删除", notes="用户管理-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		adminUserService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "用户管理-批量删除")
	@ApiOperation(value="用户管理-批量删除", notes="用户管理-批量删除")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.adminUserService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "用户管理-通过id查询")
	@ApiOperation(value="用户管理-通过id查询", notes="用户管理-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<AdminUser> queryById(@RequestParam(name="id",required=true) String id) {
		AdminUser adminUser = adminUserService.getById(id);
		if(adminUser==null) {
			return Result.error("未找到对应数据",null);
		}
		return Result.OK(adminUser);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param adminUser
    */
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, AdminUser adminUser,String ssname,String ssphone,String ssksname,String ssdwname) {
		adminUser.setName(ssname);
		adminUser.setPhone(ssphone);
		adminUser.setKsname(ssksname);
		adminUser.setDwname(ssdwname);
		adminUser.setDoctorAndSpecialist("1");
		return super.exportXls(request, adminUser, AdminUser.class, "医生账户管理");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
//        return super.importExcel1(request, response, AdminUser.class);
		MultipartHttpServletRequest multipartRequest = (MultipartHttpServletRequest) request;
		Map<String, MultipartFile> fileMap = multipartRequest.getFileMap();
		for (Map.Entry<String, MultipartFile> entity : fileMap.entrySet()) {
			MultipartFile file = entity.getValue();// 获取上传文件对象
			ImportParams params = new ImportParams();
			params.setTitleRows(2);
			params.setHeadRows(1);
			params.setNeedSave(true);
			try {
				List<AdminUser> list = ExcelImportUtil.importExcel(file.getInputStream(), AdminUser.class, params);
				int s = list.size();
				for (int i = 0;i<s;i++){
					list.get( i ).setDoctorAndSpecialist("1");
					String salt = oConvertUtils.randomGen(8);
					list.get( i ).setSalt(salt);
					if (list.get( i ).getPassword()==null){
						list.get( i ).setPassword( "123456" );
					}
					if (list.get( i ).getPassword().equals( "" )){
						list.get( i ).setPassword( "123456" );
					}
					String passwordEncode = PasswordUtil.encrypt(list.get( i ).getPhone(), list.get( i ).getPassword(), salt);
					list.get( i ).setPassword(passwordEncode);
				}
				//update-begin-author:taoyan date:20190528 for:批量插入数据
				long start = System.currentTimeMillis();
				service.saveBatch(list);
				//400条 saveBatch消耗时间1592毫秒  循环插入消耗时间1947毫秒
				//1200条  saveBatch消耗时间3687毫秒 循环插入消耗时间5212毫秒
				log.info("消耗时间" + (System.currentTimeMillis() - start) + "毫秒");
				//update-end-author:taoyan date:20190528 for:批量插入数据
				return Result.ok("文件导入成功！数据行数：" + list.size());
			} catch (Exception e) {
				//update-begin-author:taoyan date:20211124 for: 导入数据重复增加提示
				String msg = e.getMessage();
				log.error(msg, e);
				if(msg!=null && msg.indexOf("Duplicate entry")>=0){
					return Result.error("文件导入失败:有重复数据！");
				}else{
					return Result.error("文件导入失败:" + e.getMessage());
				}
				//update-end-author:taoyan date:20211124 for: 导入数据重复增加提示
			} finally {
				try {
					file.getInputStream().close();
				} catch (IOException e) {
					e.printStackTrace();
				}
			}
		}
		return Result.error("文件导入失败！");
    }
}
