package org.jeecg.modules.adminwjdc.controller;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import net.sf.json.JSONArray;
import org.apache.commons.beanutils.PropertyUtils;
import org.apache.commons.lang.StringEscapeUtils;
import org.apache.shiro.SecurityUtils;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.system.vo.LoginUser;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.adminwjdc.entity.AdminTopic;
import org.jeecg.modules.adminwjdc.entity.AdminTopic2;
import org.jeecg.modules.adminwjdc.entity.AdminTopic3;
import org.jeecg.modules.adminwjdc.service.IAdminTopicService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;

 /**
 * @Description: 问卷调查
 * @Author: jeecg-boot
 * @Date:   2023-02-25
 * @Version: V1.0
 */
@Api(tags="问卷调查")
@RestController
@RequestMapping("/adminwjdc/adminTopic")
@Slf4j
public class AdminTopicController extends JeecgController<AdminTopic, IAdminTopicService> {
	@Autowired
	private IAdminTopicService adminTopicService;
	
	/**
	 * 分页列表查询
	 *
	 * @param adminTopic
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "问卷调查-分页列表查询")
	@ApiOperation(value="问卷调查-分页列表查询", notes="问卷调查-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<AdminTopic>> queryPageList(AdminTopic adminTopic,
													@RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
													@RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
													HttpServletRequest req,String ssusername,String sstopic) {
		QueryWrapper<AdminTopic> queryWrapper = QueryGenerator.initQueryWrapper(adminTopic, req.getParameterMap());
		if (ssusername != null){
			queryWrapper.like("username",ssusername);
		}
		if (sstopic != null){
			queryWrapper.like("topic",sstopic);
		}
		Page<AdminTopic> page = new Page<AdminTopic>(pageNo, pageSize);
		IPage<AdminTopic> pageList = adminTopicService.page(page, queryWrapper);
//		for (int i = 0;i<pageList.getRecords().size();i++){
//
//		}
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param adminTopic
	 * @return
	 */
	@AutoLog(value = "问卷调查-添加")
	@ApiOperation(value="问卷调查-添加", notes="问卷调查-添加")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody AdminTopic adminTopic) {
		adminTopicService.save(adminTopic);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param adminTopic
	 * @return
	 */
	@AutoLog(value = "问卷调查-编辑")
	@ApiOperation(value="问卷调查-编辑", notes="问卷调查-编辑")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody AdminTopic adminTopic) {
		adminTopicService.updateById(adminTopic);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "问卷调查-通过id删除")
	@ApiOperation(value="问卷调查-通过id删除", notes="问卷调查-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		adminTopicService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "问卷调查-批量删除")
	@ApiOperation(value="问卷调查-批量删除", notes="问卷调查-批量删除")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.adminTopicService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "问卷调查-通过id查询")
	@ApiOperation(value="问卷调查-通过id查询", notes="问卷调查-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<AdminTopic> queryById(@RequestParam(name="id",required=true) String id) {
		AdminTopic adminTopic = adminTopicService.getById(id);
		if(adminTopic==null) {
			return Result.error("未找到对应数据",null);
		}
		return Result.OK(adminTopic);
	}

    /**
    * 导出excel
    */
    @RequestMapping(value = "/exportXls/{id}")
    public ModelAndView exportXls(@PathVariable String id) {
//        return super.exportXls(request, adminTopic, AdminTopic.class, "问卷调查");
//		QueryWrapper<AdminTopic2> queryWrapper = new QueryWrapper<>(  );
		LoginUser sysUser = (LoginUser) SecurityUtils.getSubject().getPrincipal();
		AdminTopic adminTopic = adminTopicService.getById(id);
//		String title = adminTopic.getTopicTop();
		String title = adminTopic.getTopicTop();
		String topic = adminTopic.getTopicTwo();
		String res = StringEscapeUtils.unescapeJava(topic);
//		String topic = "[{\"topicT\":\"题目1\",\"topicD\":\"答案\"}]";
		// Step.2 获取导出数据
		List<AdminTopic2> exportList = null;
		List<AdminTopic3> exportList3 = new ArrayList<>(  );
		JSONArray jsonArray = JSONArray.fromObject(res);//把String转换为json
		exportList = JSONArray.toList(jsonArray,AdminTopic2.class);

		for (int i = 0;i<exportList.size();i++){
			AdminTopic3 adminTopic3 = new AdminTopic3();
			adminTopic3.setTopicT( exportList.get( i ).getTopicT() );
			List<String> result = Arrays.asList(exportList.get( i ).getTopicD().split(","));
			adminTopic3.setA( "" );
			adminTopic3.setB( "" );
			adminTopic3.setC( "" );
			adminTopic3.setD( "" );
			adminTopic3.setE( "" );
			adminTopic3.setF( "" );
			adminTopic3.setG( "" );
			adminTopic3.setH( "" );
			adminTopic3.setI( "" );
			adminTopic3.setJ( "" );
			adminTopic3.setK( "" );
			adminTopic3.setL( "" );
//			exportList3.add( adminTopic3 );

			for (int j = 0;j<result.size();j++){
				if (j == 0){
					adminTopic3.setA( result.get( 0 ) );
				}else if (j == 1){
					adminTopic3.setB( result.get( 1 ) );
				}else if (j == 2){
					adminTopic3.setC( result.get( 2 ) );
				}else if (j == 3){
					adminTopic3.setD( result.get( 3 ) );
				}else if (j == 4){
					adminTopic3.setE( result.get( 4 ) );
				}else if (j == 5){
					adminTopic3.setF( result.get( 5 ) );
				}else if (j == 6){
					adminTopic3.setG( result.get( 6 ) );
				}else if (j == 7){
					adminTopic3.setH( result.get( 7 ) );
				}else if (j == 8){
					adminTopic3.setI( result.get( 8 ) );
				}else if (j == 9){
					adminTopic3.setJ( result.get( 9 ) );
				}else if (j == 10){
					adminTopic3.setK( result.get( 10 ) );
				}else if (j == 11){
					adminTopic3.setL( result.get( 11 ) );
				}
			}
			exportList3.add( adminTopic3 );
		}

//		List<AdminTopic2> exportList = null;


		// 过滤选中数据
//		String selections = request.getParameter("selections");
//		if (oConvertUtils.isNotEmpty(selections)) {
//			List<String> selectionList = Arrays.asList(selections.split(","));
//			exportList = pageList.stream().filter(item -> selectionList.contains(getId(item))).collect(Collectors.toList());
//		} else {
//			exportList = pageList;
//		}

		// Step.3 AutoPoi 导出Excel
		ModelAndView mv = new ModelAndView(new JeecgEntityExcelView());
		mv.addObject(NormalExcelConstants.FILE_NAME, title); //此处设置的filename无效 ,前端会重更新设置一下
		mv.addObject(NormalExcelConstants.CLASS, AdminTopic3.class);
		//update-begin--Author:liusq  Date:20210126 for：图片导出报错，ImageBasePath未设置--------------------
		ExportParams  exportParams=new ExportParams(title + "报表", "导出人:" + sysUser.getRealname(), title);
		//update-end--Author:liusq  Date:20210126 for：图片导出报错，ImageBasePath未设置----------------------
		mv.addObject(NormalExcelConstants.PARAMS,exportParams);
		mv.addObject(NormalExcelConstants.DATA_LIST, exportList3);
		return mv;
    }

	 @RequestMapping(value = "/exportXls2/{id}")
	 public ModelAndView exportXls2(@PathVariable String id) {
//        return super.exportXls(request, adminTopic, AdminTopic.class, "问卷调查");
//		QueryWrapper<AdminTopic2> queryWrapper = new QueryWrapper<>(  );
		 LoginUser sysUser = (LoginUser) SecurityUtils.getSubject().getPrincipal();
		 AdminTopic adminTopic = adminTopicService.getById(id);
//		String title = adminTopic.getTopicTop();
		 String title = adminTopic.getTopicTop();
		 String topic = adminTopic.getTopic();
		 String res = StringEscapeUtils.unescapeJava(topic);
//		String topic = "[{\"topicT\":\"题目1\",\"topicD\":\"答案\"}]";
		 // Step.2 获取导出数据
		 List<AdminTopic2> exportList = null;
		 List<AdminTopic3> exportList3 = new ArrayList<>(  );
		 JSONArray jsonArray = JSONArray.fromObject(res);//把String转换为json
		 exportList = JSONArray.toList(jsonArray,AdminTopic2.class);

		 for (int i = 0;i<exportList.size();i++){
			 AdminTopic3 adminTopic3 = new AdminTopic3();
			 adminTopic3.setTopicT( exportList.get( i ).getTopicT() );
			 List<String> result = Arrays.asList(exportList.get( i ).getTopicD().split(","));
			 adminTopic3.setA( "" );
			 adminTopic3.setB( "" );
			 adminTopic3.setC( "" );
			 adminTopic3.setD( "" );
			 adminTopic3.setE( "" );
			 adminTopic3.setF( "" );
			 adminTopic3.setG( "" );
			 adminTopic3.setH( "" );
			 adminTopic3.setI( "" );
			 adminTopic3.setJ( "" );
			 adminTopic3.setK( "" );
			 adminTopic3.setL( "" );
//			exportList3.add( adminTopic3 );

			 for (int j = 0;j<result.size();j++){
				 if (j == 0){
					 adminTopic3.setA( result.get( 0 ) );
				 }else if (j == 1){
					 adminTopic3.setB( result.get( 1 ) );
				 }else if (j == 2){
					 adminTopic3.setC( result.get( 2 ) );
				 }else if (j == 3){
					 adminTopic3.setD( result.get( 3 ) );
				 }else if (j == 4){
					 adminTopic3.setE( result.get( 4 ) );
				 }else if (j == 5){
					 adminTopic3.setF( result.get( 5 ) );
				 }else if (j == 6){
					 adminTopic3.setG( result.get( 6 ) );
				 }else if (j == 7){
					 adminTopic3.setH( result.get( 7 ) );
				 }else if (j == 8){
					 adminTopic3.setI( result.get( 8 ) );
				 }else if (j == 9){
					 adminTopic3.setJ( result.get( 9 ) );
				 }else if (j == 10){
					 adminTopic3.setK( result.get( 10 ) );
				 }else if (j == 11){
					 adminTopic3.setL( result.get( 11 ) );
				 }
			 }
			 exportList3.add( adminTopic3 );
		 }

//		List<AdminTopic2> exportList = null;


		 // 过滤选中数据
//		String selections = request.getParameter("selections");
//		if (oConvertUtils.isNotEmpty(selections)) {
//			List<String> selectionList = Arrays.asList(selections.split(","));
//			exportList = pageList.stream().filter(item -> selectionList.contains(getId(item))).collect(Collectors.toList());
//		} else {
//			exportList = pageList;
//		}

		 // Step.3 AutoPoi 导出Excel
		 ModelAndView mv = new ModelAndView(new JeecgEntityExcelView());
		 mv.addObject(NormalExcelConstants.FILE_NAME, title); //此处设置的filename无效 ,前端会重更新设置一下
		 mv.addObject(NormalExcelConstants.CLASS, AdminTopic3.class);
		 //update-begin--Author:liusq  Date:20210126 for：图片导出报错，ImageBasePath未设置--------------------
		 ExportParams  exportParams=new ExportParams(title + "报表", "导出人:" + sysUser.getRealname(), title);
		 //update-end--Author:liusq  Date:20210126 for：图片导出报错，ImageBasePath未设置----------------------
		 mv.addObject(NormalExcelConstants.PARAMS,exportParams);
		 mv.addObject(NormalExcelConstants.DATA_LIST, exportList3);
		 return mv;
	 }

	 private String getId(AdminTopic2 item) {
		 try {
			 return PropertyUtils.getProperty(item, "id").toString();
		 } catch (Exception e) {
			 e.printStackTrace();
			 return null;
		 }
	 }
    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, AdminTopic.class);
    }
}
