package org.jeecg.modules.api.controller;


import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.aliyun.dysmsapi20170525.models.SendSmsRequest;
import com.aliyun.dysmsapi20170525.models.SendSmsResponse;
import com.aliyun.tea.TeaException;
import com.aliyun.teautil.models.RuntimeOptions;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import okhttp3.OkHttpClient;
import okhttp3.Request;
import okhttp3.Response;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.constant.CommonConstant;
import org.jeecg.common.system.util.JwtUtil;
import org.jeecg.common.util.PasswordUtil;
import org.jeecg.common.util.RedisUtil;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.common.util.oss.OssBootUtil;
import org.jeecg.modules.admincasehistory.entity.AdminCaseName;
import org.jeecg.modules.admincasehistory.entity.AdminMedicalHistory;
import org.jeecg.modules.admincasehistory.entity.AdminPlatform;
import org.jeecg.modules.admincasehistory.entity.AdminUploadingName;
import org.jeecg.modules.admincasehistory.service.IAdminCaseNameService;
import org.jeecg.modules.admincasehistory.service.IAdminMedicalHistoryService;
import org.jeecg.modules.admincasehistory.service.IAdminPlatformService;
import org.jeecg.modules.admincasehistory.service.IAdminUploadingNameService;
import org.jeecg.modules.adminuser.entity.AdminUser;
import org.jeecg.modules.adminuser.service.IAdminUserService;
import org.jeecg.modules.adminwjdc.entity.AdminTopic;
import org.jeecg.modules.adminwjdc.service.IAdminTopicService;
import org.jeecg.modules.api.entity.ForgetThePasswordDTO;
import org.jeecg.modules.api.entity.SmsSendDTO;
import org.jeecg.modules.api.entity.UserDTO;
import org.jeecg.modules.base.service.BaseCommonService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.DigestUtils;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import java.io.IOException;
import java.math.BigDecimal;
import java.util.*;


@Api(tags = "用户端接口")
@RestController
@RequestMapping("/api")
@Slf4j
public class APIController {

    @Autowired
    private RedisUtil redisUtil;
    @Resource
    private BaseCommonService baseCommonService;
    @Autowired
    private IAdminPlatformService adminPlatformService;
    @Autowired
    private IAdminUserService adminUserService;
    @Autowired
    private IAdminMedicalHistoryService adminMedicalHistoryService;
    @Autowired
    private IAdminUploadingNameService adminUploadingNameService;
    @Autowired
    private IAdminCaseNameService adminCaseNameService;
    @Autowired
    private IAdminTopicService adminTopicService;


    @ApiOperation(value="上传附件和图片到OSS", notes="上传附件和图片到OSS")
    @PostMapping(value = "/uploadLocality")
    public Result<String> uploadLocality(MultipartFile file){
        Result<String> result = new Result<String>();
        try {
            String bizPath = "jeditor";
            String url = OssBootUtil.upload(file,bizPath);

            result.setMessage("上传图片成功");
            result.setResult( url );
            result.setCode( 200 );
            return result;
        }catch (Exception e){
            result.setMessage("上传图片失败");
            result.setResult( null );
            result.setCode( 0 );
            return result;
        }
    }

    @ApiOperation(value="上传附件和图片到OSS(小程序用)", notes="上传附件和图片到OSS(小程序用)")
    @PostMapping(value = "/uploadLocality2/{fileName}")
    public Result<String> uploadLocality2(MultipartFile file,@PathVariable String fileName){
        Result<String> result = new Result<String>();
        try {
            String bizPath = "jeditor";
            String url = OssBootUtil.upload2(file,bizPath,fileName);

            result.setMessage("上传图片成功");
            result.setResult( url );
            result.setCode( 200 );
            return result;
        }catch (Exception e){
            result.setMessage("上传图片失败");
            result.setResult( null );
            result.setCode( 0 );
            return result;
        }
    }
    @ApiOperation(value="获取系统配置", notes="获取系统配置")
    @PostMapping(value = "/configInfo")
    public Result<AdminPlatform> configInfo(){
        Result<AdminPlatform> result = new Result<AdminPlatform>();
        try {

            List<AdminPlatform> list = adminPlatformService.list();
            result.setMessage("获取系统配置成功");
            result.setResult( list.get( 0 ) );
            result.setCode( 200 );
            return result;
        }catch (Exception e){
            result.setMessage("获取系统配置失败");
            result.setResult( null );
            result.setCode( 0 );
            return result;
        }
    }


    @ApiOperation(value = "发送短信", notes = "发送短信，event参数 forgetpwd：忘记密码")
    @PostMapping(value = "/smsSend")
    public Result<String> smsSend(@RequestBody SmsSendDTO smsSendDTO) {

        Result<String> result = new Result<String>();
        if (smsSendDTO.getPhone().equals( "" )) {
            result.setMessage( "手机号不能为空" );
            return result;
        }
        if (smsSendDTO.getEvent().equals( "" )) {
            result.setMessage( "event参数不能为空" );
            return result;
        }

        try {
            int num = (int) ((Math.random() * 9 + 1) * 100000);
            String code = String.valueOf( num );
//             code = "123456";



            com.aliyun.dysmsapi20170525.Client client = createClient("LTAI5tD17r71nA9bfKtzcayJ", "EblO65wHRfmOtl3GrAeBbAu8i05H8O");
            com.aliyun.dysmsapi20170525.models.SendSmsRequest sendSmsRequest = new com.aliyun.dysmsapi20170525.models.SendSmsRequest()
                    .setSignName("美纳市界")
                    .setPhoneNumbers(smsSendDTO.getPhone())
                    .setTemplateCode("SMS_266705205")
                    .setTemplateParam("{\"code\":\""+code+"\"}");
            com.aliyun.teautil.models.RuntimeOptions runtime = new com.aliyun.teautil.models.RuntimeOptions();

//            com.aliyun.dysmsapi20170525.Client client = createClient("LTAI5tD17r71nA9bfKtzcayJ", "EblO65wHRfmOtl3GrAeBbAu8i05H8O");
//            SendSmsRequest sendSmsRequest = new SendSmsRequest()
//                    .setSignName("美纳市界")
//                    .setTemplateCode("SMS_266705205")
//                    .setPhoneNumbers(smsSendDTO.getPhone())
//                    .setTemplateParam("{\"code\":\""+code+"\"}");
//            RuntimeOptions runtime = new RuntimeOptions();
            // 复制代码运行请自行打印 API 的返回值
            client.sendSmsWithOptions(sendSmsRequest, runtime);
            //放入缓存
            redisUtil.set( smsSendDTO.getPhone() + smsSendDTO.getEvent() + "PhoneCode", code, 600 );



            result.setMessage( "发送成功" );
            result.setCode( 200 );
            result.setResult( code );
            return result;
        } catch (TeaException error) {
            // 如有需要，请打印 error
            com.aliyun.teautil.Common.assertAsString(error.message);
            result.setMessage( "发送请求错误" );
            return result;
        } catch (Exception _error) {
            TeaException error = new TeaException(_error.getMessage(), _error);
            // 如有需要，请打印 error
            com.aliyun.teautil.Common.assertAsString(error.message);
            result.setMessage( "发送请求错误" );
            return result;
        }
    }
    /**
     * 使用AK&SK初始化账号Client
     * @param accessKeyId
     * @param accessKeySecret
     * @return Client
     * @throws Exception
     */
    public static com.aliyun.dysmsapi20170525.Client createClient(String accessKeyId, String accessKeySecret) throws Exception {
        com.aliyun.teaopenapi.models.Config config = new com.aliyun.teaopenapi.models.Config()
                // 必填，您的 AccessKey ID
                .setAccessKeyId(accessKeyId)
                // 必填，您的 AccessKey Secret
                .setAccessKeySecret(accessKeySecret);
        // 访问的域名
        config.endpoint = "dysmsapi.aliyuncs.com";
        return new com.aliyun.dysmsapi20170525.Client(config);
    }
//    public static com.aliyun.dysmsapi20170525.Client createClient(String accessKeyId, String accessKeySecret) throws Exception {
//        com.aliyun.teaopenapi.models.Config config = new com.aliyun.teaopenapi.models.Config()
//                // 您的 AccessKey ID
//                .setAccessKeyId(accessKeyId)
//                // 您的 AccessKey Secret
//                .setAccessKeySecret(accessKeySecret);
//        // 访问的域名
//        config.endpoint = "dysmsapi.ap-southeast-1.aliyuncs.com";
//        return new com.aliyun.dysmsapi20170525.Client(config);
//    }

    @ApiOperation(value = "用户登录", notes = "用户登录")
    @PostMapping(value = "/passwordLogin")
    public Result<JSONObject> passwordLogin(@RequestBody UserDTO UserDTO) {
        Result<JSONObject> result = new Result<JSONObject>();
        JSONObject obj = new JSONObject();
        if (UserDTO.getPhone().equals( "" )) {
            result.setMessage( "手机号不能为空" );
            return result;
        }
        if (UserDTO.getPassword().equals( "" )) {
            result.setMessage( "密码不能为空" );
            return result;
        }
        //1. 校验用户是否有效
        //update-begin-author:wangshuai date:20200601 for: 登录代码验证用户是否注销bug，if条件永远为false
        QueryWrapper<AdminUser> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq( "phone", UserDTO.getPhone() );
        queryWrapper.eq( "doctor_and_specialist", UserDTO.getSf() );
        AdminUser storeMember = adminUserService.getOne( queryWrapper );

        if (storeMember == null) {
            result.setMessage( "该用户不存在" );
            baseCommonService.addLog( "用户登录失败，用户不存在！", CommonConstant.LOG_TYPE_1, null );
            return result;
        }
        //2. 校验用户名或密码是否正确
        String userpassword = PasswordUtil.encrypt( UserDTO.getPhone(), UserDTO.getPassword(), storeMember.getSalt() );
        String syspassword = storeMember.getPassword();
        if (!syspassword.equals( userpassword )) {
            result.setMessage( "用户名或密码错误" );
            return result;
        }
        log.info( "手机号：" + UserDTO.getPhone() + "登录成功===========" );
        //生成token================
        String token = JwtUtil.sign( storeMember.getPhone(), storeMember.getPassword() );
//       // 设置token缓存有效时间
        redisUtil.set( CommonConstant.PREFIX_NFT_USER_TOKEN + UserDTO.getPhone(), token );
        redisUtil.expire( CommonConstant.PREFIX_NFT_USER_TOKEN + UserDTO.getPhone(), 60 * 60 * 24 );
//       redisUtil.expire(CommonConstant.PREFIX_NFT_USER_TOKEN + token, 60);
        result.setMessage( "登录成功" );
        obj.put( "token", token );
        result.setResult( obj );
        result.setCode( 200 );

        return result;
    }


    @ApiOperation(value = "忘记密码", notes = "忘记密码")
    @PostMapping(value = "/ForgetPassword")
    public Result<JSONObject> ForgetPassword(@RequestBody ForgetThePasswordDTO forgetThePasswordDTO) {
        Result<JSONObject> result = new Result<JSONObject>();
        JSONObject obj = new JSONObject();
        if (forgetThePasswordDTO.getPhone().equals( "" )) {
            result.setMessage( "手机号不能为空" );
            return result;
        }
        if (forgetThePasswordDTO.getVer_code().equals( "" )) {
            result.setMessage( "验证码不能为空" );
            return result;
        }
        if (forgetThePasswordDTO.getPassword().equals( "" )) {
            result.setMessage( "密码不能为空" );
            return result;
        }
        if (forgetThePasswordDTO.getConfirm_password().equals( "" )) {
            result.setMessage( "确认密码不能为空" );
            return result;
        }
        if (!forgetThePasswordDTO.getPassword().equals( forgetThePasswordDTO.getConfirm_password() )) {
            result.setMessage( "确认密码和密码不一致" );
            return result;
        }
        //1. 校验用户是否有效
        AdminUser u = adminUserService.getOne( new QueryWrapper<AdminUser>().eq( "phone",
                forgetThePasswordDTO.getPhone() ) );
        if (u == null) {
            result.setMessage( "该用户不存在，请注册" );
            baseCommonService.addLog( "用户登录失败，用户不存在！", CommonConstant.LOG_TYPE_1, null );
            return result;
        }
        //校验验证码
        if (redisUtil.hasKey( forgetThePasswordDTO.getPhone() + "forgetpwdPhoneCode" )) {
            String code = String.valueOf( redisUtil.get( forgetThePasswordDTO.getPhone() + "forgetpwdPhoneCode" ) );
            if (!forgetThePasswordDTO.getVer_code().equals( code )) {
                result.setMessage( "手机验证码不对" );
                return result;
            }
        }
        if (!redisUtil.hasKey( forgetThePasswordDTO.getPhone() + "forgetpwdPhoneCode" )) {
            result.setMessage( "手机验证码过期" );
            return result;
        }

        redisUtil.del( forgetThePasswordDTO.getPhone() + "forgetpwdPhoneCode" );
        AdminUser adminUser = new AdminUser();
        adminUser.setId( u.getId() );
        String salt = oConvertUtils.randomGen(8);
        adminUser.setSalt(salt);
        String passwordEncode = PasswordUtil.encrypt( forgetThePasswordDTO.getPhone(), forgetThePasswordDTO.getPassword(), salt );
        adminUser.setPassword( passwordEncode );
        adminUserService.updateById( adminUser );

        log.info( "手机号：" + forgetThePasswordDTO.getPhone() + "修改密码成功===========" );

        //生成token================
        String token = JwtUtil.sign( forgetThePasswordDTO.getPhone(), adminUser.getPassword() );
//       // 设置token缓存有效时间
        redisUtil.set( CommonConstant.PREFIX_NFT_USER_TOKEN + forgetThePasswordDTO.getPhone(), token );
        redisUtil.expire( CommonConstant.PREFIX_NFT_USER_TOKEN + forgetThePasswordDTO.getPhone(), 60 * 60 * 24 );
        obj.put( "token", token );

        result.setResult( obj );
        result.setMessage( "修改密码成功" );
        result.setCode( 200 );

        log.info( "手机号：" + forgetThePasswordDTO.getPhone() + "登录成功===========" );

        return result;
    }

    @ApiOperation(value = "获取个人信息", notes = "获取个人信息")
    @PostMapping(value = "/getUserInfo")
    public Result<AdminUser> getUserInfo(@RequestHeader("Authorization") String Authorization) {
        Result<AdminUser> result = new Result<AdminUser>();
        if (Authorization.equals( "" )) {
            result.setMessage( "token不能为空" );
            return result;
        }

        String userPhone = JwtUtil.getUsername( Authorization );

        //校验token==================
        if (!redisUtil.hasKey( CommonConstant.PREFIX_NFT_USER_TOKEN + userPhone )) {
            result.setMessage( "TOKEN失效" );
            result.setCode( 201 );
            return result;
        }
        try {


            //1. 校验用户是否有效
            //update-begin-author:wangshuai date:20200601 for: 登录代码验证用户是否注销bug，if条件永远为false
            QueryWrapper<AdminUser> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq( "phone", userPhone );
            AdminUser storeMember1 = adminUserService.getOne( queryWrapper );

            if (storeMember1 == null) {
                result.setMessage( "token校验该用户不存在" );
                baseCommonService.addLog( "用户校验失败，用户不存在！", CommonConstant.LOG_TYPE_1, null );
                return result;
            }

            result.setMessage( "获取个人信息成功" );
            result.setResult( storeMember1 );
            result.setCode( 200 );
            return result;
        } catch (Exception e) {
            result.setMessage( "获取个人信息失败" );
            result.setResult( null );
            result.setCode( 0 );
            return result;
        }
    }

    @ApiOperation(value = "获取上传分类", notes = "获取上传分类")
    @PostMapping(value = "/getUploadingName")
    public Result<List<AdminUploadingName>> getUploadingName() {
        Result<List<AdminUploadingName>> result = new Result<List<AdminUploadingName>>();

        try {


//            QueryWrapper<AdminUser> queryWrapper = new QueryWrapper<>();
//            queryWrapper.eq( "phone", userPhone );
//            AdminUser storeMember1 = adminUserService.getOne( queryWrapper );

            List<AdminUploadingName> list = adminUploadingNameService.list();


            result.setMessage( "获取上传分类成功" );
            result.setResult( list );
            result.setCode( 200 );
            return result;
        } catch (Exception e) {
            result.setMessage( "获取上传分类失败" );
            result.setResult( null );
            result.setCode( 0 );
            return result;
        }
    }

    @ApiOperation(value = "获取病历分类", notes = "获取病历分类")
    @PostMapping(value = "/getCaseName")
    public Result<List<AdminCaseName>> getCaseName() {
        Result<List<AdminCaseName>> result = new Result<List<AdminCaseName>>();

        try {

            List<AdminCaseName> list = adminCaseNameService.list();

            result.setMessage( "获取病历分类成功" );
            result.setResult( list );
            result.setCode( 200 );
            return result;
        } catch (Exception e) {
            result.setMessage( "获取病历分类失败" );
            result.setResult( null );
            result.setCode( 0 );
            return result;
        }
    }

    @ApiOperation(value = "完善个人信息", notes = "完善个人信息")
    @PostMapping(value = "/completeInformation")
    public Result<Boolean> completeInformation(@RequestHeader("Authorization") String Authorization,
                                               @RequestBody AdminUser adminUser) {
        Result<Boolean> result = new Result<Boolean>();
        if (Authorization.equals( "" )) {
            result.setMessage( "token不能为空" );
            return result;
        }

        String userPhone = JwtUtil.getUsername( Authorization );

        //校验token==================
        if (!redisUtil.hasKey( CommonConstant.PREFIX_NFT_USER_TOKEN + userPhone )) {
            result.setMessage( "TOKEN失效" );
            result.setCode( 201 );
            return result;
        }
        try {

            //1. 校验用户是否有效
            QueryWrapper<AdminUser> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq( "phone", userPhone );
            AdminUser storeMember1 = adminUserService.getOne( queryWrapper );

            if (storeMember1 == null) {
                result.setMessage( "token校验该用户不存在" );
                baseCommonService.addLog( "用户校验失败，用户不存在！", CommonConstant.LOG_TYPE_1, null );
                return result;
            }
            adminUser.setId( storeMember1.getId() );
            adminUserService.updateById(adminUser);

            result.setMessage( "完善个人信息成功" );
            result.setResult( true );
            result.setCode( 200 );
            return result;
        } catch (Exception e) {
            result.setMessage( "完善个人信息失败" );
            result.setResult( null );
            result.setCode( 0 );
            return result;
        }
    }

    @ApiOperation(value = "病例上传", notes = "病例上传")
    @PostMapping(value = "/patientQuide")
    public Result<Boolean> patientQuide(@RequestHeader("Authorization") String Authorization,
                                               @RequestBody AdminMedicalHistory adminMedicalHistory) {
        Result<Boolean> result = new Result<Boolean>();
        if (Authorization.equals( "" )) {
            result.setMessage( "token不能为空" );
            return result;
        }

        String userPhone = JwtUtil.getUsername( Authorization );

        //校验token==================
        if (!redisUtil.hasKey( CommonConstant.PREFIX_NFT_USER_TOKEN + userPhone )) {
            result.setMessage( "TOKEN失效" );
            result.setCode( 201 );
            return result;
        }
        try {

            //1. 校验用户是否有效
            QueryWrapper<AdminUser> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq( "phone", userPhone );
            AdminUser storeMember1 = adminUserService.getOne( queryWrapper );

            if (storeMember1 == null) {
                result.setMessage( "token校验该用户不存在" );
                baseCommonService.addLog( "用户校验失败，用户不存在！", CommonConstant.LOG_TYPE_1, null );
                return result;
            }
            adminMedicalHistory.setPhone(userPhone);
            //初始化状态数据
            adminMedicalHistory.setIsSecondaryUpload("3");
            adminMedicalHistory.setFirstTrial("0");
            adminMedicalHistory.setSecondaryUpload("1");
            adminMedicalHistory.setType("0");
            adminMedicalHistory.setAllocation("1");
            //复制一份上传的图片  给上传者看
            adminMedicalHistory.setPicTwo(adminMedicalHistory.getPic());
            adminMedicalHistoryService.save(adminMedicalHistory);

            result.setMessage( "病例上传成功" );
            result.setResult( true );
            result.setCode( 200 );
            return result;
        } catch (Exception e) {
            result.setMessage( "病例上传失败" );
            result.setResult( null );
            result.setCode( 0 );
            return result;
        }
    }

    @ApiOperation(value = "病例编辑", notes = "病例编辑")
    @PostMapping(value = "/patientQuideEdit")
    public Result<String> patientQuideEdit(@RequestBody AdminMedicalHistory adminMedicalHistory) {
        adminMedicalHistoryService.updateById(adminMedicalHistory);
        return Result.OK("编辑成功!");
    }

    @ApiOperation(value = "病例上传记录列表", notes = "病例上传")
    @PostMapping(value = "/patientQuideByPhongList")
    public Result< List<AdminMedicalHistory>> patientQuideByPhongList(@RequestHeader("Authorization") String Authorization) {
        Result< List<AdminMedicalHistory>> result = new Result< List<AdminMedicalHistory>>();
        if (Authorization.equals( "" )) {
            result.setMessage( "token不能为空" );
            return result;
        }

        String userPhone = JwtUtil.getUsername( Authorization );

        //校验token==================
        if (!redisUtil.hasKey( CommonConstant.PREFIX_NFT_USER_TOKEN + userPhone )) {
            result.setMessage( "TOKEN失效" );
            result.setCode( 201 );
            return result;
        }
        try {

            //1. 校验用户是否有效
            QueryWrapper<AdminUser> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq( "phone", userPhone );
            AdminUser storeMember1 = adminUserService.getOne( queryWrapper );

            if (storeMember1 == null) {
                result.setMessage( "token校验该用户不存在" );
                baseCommonService.addLog( "用户校验失败，用户不存在！", CommonConstant.LOG_TYPE_1, null );
                return result;
            }
            QueryWrapper<AdminMedicalHistory> queryWrapper2 = new QueryWrapper<>();
            queryWrapper2.eq("phone",userPhone);
            queryWrapper2.orderByDesc("create_time");
            List<AdminMedicalHistory> list = adminMedicalHistoryService.list(queryWrapper2);

            result.setMessage( "获取病例上传记录列表成功" );
            result.setResult( list );
            result.setCode( 200 );
            return result;
        } catch (Exception e) {
            result.setMessage( "获取病例上传记录列表失败" );
            result.setResult( null );
            result.setCode( 0 );
            return result;
        }
    }

    @ApiOperation(value = "专家账号病例列表", notes = "专家账号病例列表")
    @PostMapping(value = "/patientListZj")
    public Result< List<AdminMedicalHistory>> patientListZj(@RequestHeader("Authorization") String Authorization) {
        Result< List<AdminMedicalHistory>> result = new Result< List<AdminMedicalHistory>>();
        if (Authorization.equals( "" )) {
            result.setMessage( "token不能为空" );
            return result;
        }

        String userPhone = JwtUtil.getUsername( Authorization );

        //校验token==================
        if (!redisUtil.hasKey( CommonConstant.PREFIX_NFT_USER_TOKEN + userPhone )) {
            result.setMessage( "TOKEN失效" );
            result.setCode( 201 );
            return result;
        }
        try {

            //1. 校验用户是否有效
            QueryWrapper<AdminUser> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq( "phone", userPhone );
            AdminUser storeMember1 = adminUserService.getOne( queryWrapper );

            if (storeMember1 == null) {
                result.setMessage( "token校验该用户不存在" );
                baseCommonService.addLog( "用户校验失败，用户不存在！", CommonConstant.LOG_TYPE_1, null );
                return result;
            }
            QueryWrapper<AdminMedicalHistory> queryWrapper2 = new QueryWrapper<>();
//            queryWrapper2.eq("allocation_zjphone",userPhone)
//                    .eq( "secondary_upload","2" )
//            .or()
//                    .eq( "allocation_zjphone",userPhone )
//                    .eq( "is_secondary_upload","3" );

            queryWrapper2.eq("allocation_zjphone",userPhone);
            queryWrapper2.eq( "allocation","2" );
            List<AdminMedicalHistory> list = adminMedicalHistoryService.list(queryWrapper2);

            result.setMessage( "获取专家账号病例列表成功" );
            result.setResult( list );
            result.setCode( 200 );
            return result;
        } catch (Exception e) {
            result.setMessage( "获取专家账号病例列表失败" );
            result.setResult( null );
            result.setCode( 0 );
            return result;
        }
    }

    @ApiOperation(value = "病例审核", notes = "病例审核")
    @PostMapping(value = "/patientGuide")
    public Result<Boolean> patientGuide(@RequestHeader("Authorization") String Authorization,
                                        @RequestBody AdminMedicalHistory adminMedicalHistory) {
        Result<Boolean> result = new Result<Boolean>();
        if (Authorization.equals( "" )) {
            result.setMessage( "token不能为空" );
            return result;
        }

        String userPhone = JwtUtil.getUsername( Authorization );

        //校验token==================
        if (!redisUtil.hasKey( CommonConstant.PREFIX_NFT_USER_TOKEN + userPhone )) {
            result.setMessage( "TOKEN失效" );
            result.setCode( 201 );
            return result;
        }
        try {

            //1. 校验用户是否有效
            QueryWrapper<AdminUser> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq( "phone", userPhone );
            AdminUser storeMember1 = adminUserService.getOne( queryWrapper );

            if (storeMember1 == null) {
                result.setMessage( "token校验该用户不存在" );
                baseCommonService.addLog( "用户校验失败，用户不存在！", CommonConstant.LOG_TYPE_1, null );
                return result;
            }

            if (adminMedicalHistory.getId()==null){
                result.setMessage( "token不能为空" );
                return result;
            }
            adminMedicalHistoryService.updateById(adminMedicalHistory);

            result.setMessage( "病例审核成功" );
            result.setResult( true );
            result.setCode( 200 );
            return result;
        } catch (Exception e) {
            result.setMessage( "病例审核失败" );
            result.setResult( null );
            result.setCode( 0 );
            return result;
        }
    }


    @ApiOperation(value = "问卷调查", notes = "问卷调查")
    @PostMapping(value = "/topicAdd")
    public Result<Boolean> topicAdd(@RequestHeader("Authorization") String Authorization,
                                        @RequestBody AdminTopic adminTopic) {
        Result<Boolean> result = new Result<Boolean>();
        if (Authorization.equals( "" )) {
            result.setMessage( "token不能为空" );
            return result;
        }

        String userPhone = JwtUtil.getUsername( Authorization );

        //校验token==================
        if (!redisUtil.hasKey( CommonConstant.PREFIX_NFT_USER_TOKEN + userPhone )) {
            result.setMessage( "TOKEN失效" );
            result.setCode( 201 );
            return result;
        }
        try {

            //1. 校验用户是否有效
            QueryWrapper<AdminUser> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq( "phone", userPhone );
            AdminUser storeMember1 = adminUserService.getOne( queryWrapper );

            if (storeMember1 == null) {
                result.setMessage( "token校验该用户不存在" );
                baseCommonService.addLog( "用户校验失败，用户不存在！", CommonConstant.LOG_TYPE_1, null );
                return result;
            }
            adminTopic.setUsername( storeMember1.getName() );
            adminTopicService.save(adminTopic);

            result.setMessage( "问卷调查提交成功" );
            result.setResult( true );
            result.setCode( 200 );
            return result;
        } catch (Exception e) {
            result.setMessage( "问卷调查提交失败" );
            result.setResult( null );
            result.setCode( 0 );
            return result;
        }
    }

    @ApiOperation(value = "获取个人问卷调查次数", notes = "获取个人问卷调查次数")
    @PostMapping(value = "/getTopicNum")
    public Result<Integer> getTopicNum(@RequestHeader("Authorization") String Authorization) {
        Result<Integer> result = new Result<Integer>();
        if (Authorization.equals( "" )) {
            result.setMessage( "token不能为空" );
            return result;
        }

        String userPhone = JwtUtil.getUsername( Authorization );

        //校验token==================
        if (!redisUtil.hasKey( CommonConstant.PREFIX_NFT_USER_TOKEN + userPhone )) {
            result.setMessage( "TOKEN失效" );
            result.setCode( 201 );
            return result;
        }
        try {


            //1. 校验用户是否有效
            //update-begin-author:wangshuai date:20200601 for: 登录代码验证用户是否注销bug，if条件永远为false
            QueryWrapper<AdminUser> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq( "phone", userPhone );
            AdminUser storeMember1 = adminUserService.getOne( queryWrapper );

            if (storeMember1 == null) {
                result.setMessage( "token校验该用户不存在" );
                baseCommonService.addLog( "用户校验失败，用户不存在！", CommonConstant.LOG_TYPE_1, null );
                return result;
            }

            QueryWrapper<AdminTopic> queryWrapper2 = new QueryWrapper<>();
            queryWrapper2.eq( "username", storeMember1.getName() );
            List<AdminTopic> list = adminTopicService.listNum( queryWrapper2 );

            result.setMessage( "获取个人问卷调查次数成功" );
            result.setResult( list.size() );
            result.setCode( 200 );
            return result;
        } catch (Exception e) {
            result.setMessage( "获取个人问卷调查次数失败" );
            result.setResult( null );
            result.setCode( 0 );
            return result;
        }
    }
}
