package org.jeecg.modules.system.controller;

import java.io.UnsupportedEncodingException;
import java.io.IOException;
import java.net.URLDecoder;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.jeecg.modules.system.entity.NftOrderInfo;
import org.jeecg.modules.system.entity.NftUser;
import org.jeecg.modules.system.service.INftOrderInfoService;
import org.jeecg.modules.system.service.INftUserService;
import org.jeecg.modules.system.vo.NftUserPage;
import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.vo.LoginUser;
import org.apache.shiro.SecurityUtils;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;

import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;

 /**
 * @Description: NFT用户信息
 * @Author: jeecg-boot
 * @Date:   2022-06-18
 * @Version: V1.0
 */
@Api(tags="NFT用户信息")
@RestController
@RequestMapping("/nft/nftUser")
@Slf4j
public class NftUserController {
	@Autowired
	private INftUserService nftUserService;
	@Autowired
	private INftOrderInfoService nftOrderInfoService;
	
	/**
	 * 分页列表查询
	 *
	 * @param nftUser
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	@AutoLog(value = "NFT用户信息-分页列表查询")
	@ApiOperation(value="NFT用户信息-分页列表查询", notes="NFT用户信息-分页列表查询")
	@GetMapping(value = "/list")
	public Result<?> queryPageList(NftUser nftUser,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<NftUser> queryWrapper = QueryGenerator.initQueryWrapper(nftUser, req.getParameterMap());
		Page<NftUser> page = new Page<NftUser>(pageNo, pageSize);
		IPage<NftUser> pageList = nftUserService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param nftUserPage
	 * @return
	 */
	@AutoLog(value = "NFT用户信息-添加")
	@ApiOperation(value="NFT用户信息-添加", notes="NFT用户信息-添加")
	@PostMapping(value = "/add")
	public Result<?> add(@RequestBody NftUserPage nftUserPage) {
		NftUser nftUser = new NftUser();
		BeanUtils.copyProperties(nftUserPage, nftUser);
		nftUserService.saveMain(nftUser, nftUserPage.getNftOrderInfoList());
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param nftUserPage
	 * @return
	 */
	@AutoLog(value = "NFT用户信息-编辑")
	@ApiOperation(value="NFT用户信息-编辑", notes="NFT用户信息-编辑")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<?> edit(@RequestBody NftUserPage nftUserPage) {
		NftUser nftUser = new NftUser();
		BeanUtils.copyProperties(nftUserPage, nftUser);
		NftUser nftUserEntity = nftUserService.getById(nftUser.getId());
		if(nftUserEntity==null) {
			return Result.error("未找到对应数据");
		}
		nftUserService.updateMain(nftUser, nftUserPage.getNftOrderInfoList());
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "NFT用户信息-通过id删除")
	@ApiOperation(value="NFT用户信息-通过id删除", notes="NFT用户信息-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<?> delete(@RequestParam(name="id",required=true) String id) {
		nftUserService.delMain(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "NFT用户信息-批量删除")
	@ApiOperation(value="NFT用户信息-批量删除", notes="NFT用户信息-批量删除")
	@DeleteMapping(value = "/deleteBatch")
	public Result<?> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.nftUserService.delBatchMain(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功！");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "NFT用户信息-通过id查询")
	@ApiOperation(value="NFT用户信息-通过id查询", notes="NFT用户信息-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<?> queryById(@RequestParam(name="id",required=true) String id) {
		NftUser nftUser = nftUserService.getById(id);
		if(nftUser==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(nftUser);

	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "收藏明细-通过主表ID查询")
	@ApiOperation(value="收藏明细-通过主表ID查询", notes="收藏明细-通过主表ID查询")
	@GetMapping(value = "/queryNftOrderInfoByMainId")
	public Result<?> queryNftOrderInfoListByMainId(@RequestParam(name="id",required=true) String id) {
		List<NftOrderInfo> nftOrderInfoList = nftOrderInfoService.selectByMainId(id);
		IPage <NftOrderInfo> page = new Page<>();
		page.setRecords(nftOrderInfoList);
		page.setTotal(nftOrderInfoList.size());
		return Result.OK(page);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param nftUser
    */
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, NftUser nftUser) {
      // Step.1 组装查询条件查询数据
      QueryWrapper<NftUser> queryWrapper = QueryGenerator.initQueryWrapper(nftUser, request.getParameterMap());
      LoginUser sysUser = (LoginUser) SecurityUtils.getSubject().getPrincipal();

      //Step.2 获取导出数据
      List<NftUser> queryList = nftUserService.list(queryWrapper);
      // 过滤选中数据
      String selections = request.getParameter("selections");
      List<NftUser> nftUserList = new ArrayList<NftUser>();
      if(oConvertUtils.isEmpty(selections)) {
          nftUserList = queryList;
      }else {
          List<String> selectionList = Arrays.asList(selections.split(","));
          nftUserList = queryList.stream().filter(item -> selectionList.contains(item.getId())).collect(Collectors.toList());
      }

      // Step.3 组装pageList
      List<NftUserPage> pageList = new ArrayList<NftUserPage>();
      for (NftUser main : nftUserList) {
          NftUserPage vo = new NftUserPage();
          BeanUtils.copyProperties(main, vo);
          List<NftOrderInfo> nftOrderInfoList = nftOrderInfoService.selectByMainId(main.getId());
          vo.setNftOrderInfoList(nftOrderInfoList);
          pageList.add(vo);
      }

      // Step.4 AutoPoi 导出Excel
      ModelAndView mv = new ModelAndView(new JeecgEntityExcelView());
      mv.addObject(NormalExcelConstants.FILE_NAME, "NFT用户信息列表");
      mv.addObject(NormalExcelConstants.CLASS, NftUserPage.class);
      mv.addObject(NormalExcelConstants.PARAMS, new ExportParams("NFT用户信息数据", "导出人:"+sysUser.getRealname(), "NFT用户信息"));
      mv.addObject(NormalExcelConstants.DATA_LIST, pageList);
      return mv;
    }

    /**
    * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
      MultipartHttpServletRequest multipartRequest = (MultipartHttpServletRequest) request;
      Map<String, MultipartFile> fileMap = multipartRequest.getFileMap();
      for (Map.Entry<String, MultipartFile> entity : fileMap.entrySet()) {
          MultipartFile file = entity.getValue();// 获取上传文件对象
          ImportParams params = new ImportParams();
          params.setTitleRows(2);
          params.setHeadRows(1);
          params.setNeedSave(true);
          try {
              List<NftUserPage> list = ExcelImportUtil.importExcel(file.getInputStream(), NftUserPage.class, params);
              for (NftUserPage page : list) {
                  NftUser po = new NftUser();
                  BeanUtils.copyProperties(page, po);
                  nftUserService.saveMain(po, page.getNftOrderInfoList());
              }
              return Result.OK("文件导入成功！数据行数:" + list.size());
          } catch (Exception e) {
              log.error(e.getMessage(),e);
              return Result.error("文件导入失败:"+e.getMessage());
          } finally {
              try {
                  file.getInputStream().close();
              } catch (IOException e) {
                  e.printStackTrace();
              }
          }
      }
      return Result.OK("文件导入失败！");
    }

}
