package org.jeecg.modules.system.service.impl;


import org.jeecg.modules.system.entity.NftOrderInfo;
import org.jeecg.modules.system.entity.NftUser;
import org.jeecg.modules.system.mapper.NftOrderInfoMapper;
import org.jeecg.modules.system.mapper.NftUserMapper;
import org.jeecg.modules.system.service.INftUserService;
import org.springframework.stereotype.Service;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;
import java.io.Serializable;
import java.util.List;
import java.util.Collection;

/**
 * @Description: NFT用户信息
 * @Author: jeecg-boot
 * @Date:   2022-06-18
 * @Version: V1.0
 */
@Service
public class NftUserServiceImpl extends ServiceImpl<NftUserMapper, NftUser> implements INftUserService {

	@Autowired
	private NftUserMapper nftUserMapper;
	@Autowired
	private NftOrderInfoMapper nftOrderInfoMapper;
	
	@Override
	@Transactional
	public void saveMain(NftUser nftUser, List<NftOrderInfo> nftOrderInfoList) {
		nftUserMapper.insert(nftUser);
		if(nftOrderInfoList!=null && nftOrderInfoList.size()>0) {
			for(NftOrderInfo entity:nftOrderInfoList) {
				//外键设置
				entity.setMid(nftUser.getId());
				nftOrderInfoMapper.insert(entity);
			}
		}
	}

	@Override
	@Transactional
	public void updateMain(NftUser nftUser,List<NftOrderInfo> nftOrderInfoList) {
		nftUserMapper.updateById(nftUser);
		
		//1.先删除子表数据
		nftOrderInfoMapper.deleteByMainId(nftUser.getId());
		
		//2.子表数据重新插入
		if(nftOrderInfoList!=null && nftOrderInfoList.size()>0) {
			for(NftOrderInfo entity:nftOrderInfoList) {
				//外键设置
				entity.setMid(nftUser.getId());
				nftOrderInfoMapper.insert(entity);
			}
		}
	}

	@Override
	@Transactional
	public void delMain(String id) {
		nftOrderInfoMapper.deleteByMainId(id);
		nftUserMapper.deleteById(id);
	}

	@Override
	@Transactional
	public void delBatchMain(Collection<? extends Serializable> idList) {
		for(Serializable id:idList) {
			nftOrderInfoMapper.deleteByMainId(id.toString());
			nftUserMapper.deleteById(id);
		}
	}
	
}
